# GEOGloWS
[![Anaconda-Server Badge](https://anaconda.org/geoglows/geoglows/badges/version.svg)](https://anaconda.org/geoglows/geoglows)
[![Anaconda-Server Badge](https://anaconda.org/geoglows/geoglows/badges/latest_release_date.svg)](https://anaconda.org/geoglows/geoglows)
[![Anaconda-Server Badge](https://anaconda.org/geoglows/geoglows/badges/installer/conda.svg)](https://conda.anaconda.org/rileyhales)
[![Anaconda-Server Badge](https://anaconda.org/geoglows/geoglows/badges/downloads.svg)](https://anaconda.org/geoglows/geoglows)
[![Documentation Status](https://readthedocs.org/projects/geoglows/badge/?version=latest)](https://geoglows.readthedocs.io/en/latest/?badge=latest)

[Visit the Anaconda Cloud page](https://anaconda.org/geoglows/geoglows)
```bash
conda install -c geoglows geoglows
```

Also available on pypi

[Visit the PyPi page](https://pypi.org/project/geoglows)

```bash
pip install geoglows
```

Tools to access and process data coming from the GEOGloWS initiative.

https://geoglows.readthedocs.io